MarkTraceur has uploaded a new change for review.

  https://gerrit.wikimedia.org/r/294112

Change subject: Rename to match repository
......................................................................

Rename to match repository

I messed up the repository request, but I'm sure Gerrit admins
would prefer that I do this.

Change-Id: I1fd7f6ff9b5a7238393b91f22ab7b0e751891fb8
---
R FileAnnotations.hooks.php
R FileAnnotations.php
M extension.json
R resources/src/fileannotations.js
R resources/src/fileannotations.less
5 files changed, 23 insertions(+), 23 deletions(-)


  git pull 
ssh://gerrit.wikimedia.org:29418/mediawiki/extensions/FileAnnotations 
refs/changes/12/294112/1

diff --git a/FileAnnotator.php b/FileAnnotations.php
similarity index 79%
rename from FileAnnotator.php
rename to FileAnnotations.php
index 5ae7aad..1a54c68 100644
--- a/FileAnnotator.php
+++ b/FileAnnotations.php
@@ -13,9 +13,9 @@
  */
 
 if ( function_exists( 'wfLoadExtension' ) ) {
-       wfLoadExtension( 'FileAnnotator' );
+       wfLoadExtension( 'FileAnnotations' );
 
        return true;
 }
 
-die( 'This version of the FileAnnotator extension requires MediaWiki 1.25+.' );
+die( 'This version of the FileAnnotations extension requires MediaWiki 1.25+.' 
);
diff --git a/extension.json b/extension.json
index a3b28a2..a2fda22 100644
--- a/extension.json
+++ b/extension.json
@@ -1,36 +1,36 @@
 {
-       "name": "FileAnnotator",
+       "name": "FileAnnotations",
        "version": "0.0.1",
        "author": [
                "Mark Holmquist"
        ],
-       "url": "https://www.mediawiki.org/wiki/Extension:FileAnnotator";,
-       "descriptionmsg": "fileannotator-desc",
+       "url": "https://www.mediawiki.org/wiki/Extension:FileAnnotations";,
+       "descriptionmsg": "fileannotations-desc",
        "license-name": "GPL-3.0",
        "type": "other",
-       "callback": "FileAnnotatorHooks::onRegistration",
+       "callback": "FileAnnotationsHooks::onRegistration",
        "APIModules": {
-               "fileannotator": {
-                       "class": "ApiFileAnnotator"
+               "fileannotations": {
+                       "class": "ApiFileAnnotations"
                }
        },
        "MessagesDirs": {
-               "FileAnnotator": [
+               "FileAnnotations": [
                        "i18n"
                ]
        },
        "Hooks": {
-               "BeforePageDisplay": 
"FileAnnotatorHooks::getModulesForFilePage",
-               "ParserFirstCallInit": "FileAnnotatorHooks::onParserSetup"
+               "BeforePageDisplay": 
"FileAnnotationsHooks::getModulesForFilePage",
+               "ParserFirstCallInit": "FileAnnotationsHooks::onParserSetup"
        },
        "ResourceModules": {
-               "fileannotator": {
+               "fileannotations": {
                        "scripts": [
-                               "resources/src/fileannotator.js"
+                               "resources/src/fileannotations.js"
                        ],
 
                        "styles": [
-                               "resources/src/fileannotator.less"
+                               "resources/src/fileannotations.less"
                        ],
 
                        "dependencies": [
@@ -40,16 +40,16 @@
        },
        "ResourceFileModulePaths": {
                "localBasePath": "",
-               "remoteExtPath": "FileAnnotator"
+               "remoteExtPath": "FileAnnotations"
        },
        "ExtensionFunctions": [
-               "FileAnnotatorHooks::onSetup"
+               "FileAnnotationsHooks::onSetup"
        ],
        "AutoloadClasses": {
-               "FileAnnotatorHooks": "FileAnnotator.hooks.php"
+               "FileAnnotationsHooks": "FileAnnotations.hooks.php"
        },
        "ConfigRegistry": {
-               "fileannotator": "GlobalVarConfig::newInstance"
+               "fileannotations": "GlobalVarConfig::newInstance"
        },
        "manifest_version": 1
 }
diff --git a/FileAnnotator.hooks.php b/FileAnnotations.hooks.php
similarity index 87%
rename from FileAnnotator.hooks.php
rename to FileAnnotations.hooks.php
index 84f6f19..4ebe9bf 100644
--- a/FileAnnotator.hooks.php
+++ b/FileAnnotations.hooks.php
@@ -1,6 +1,6 @@
 <?php
 /**
  * Hooks for FileAnnotator extension
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
  * @ingroup Extensions
  */
 
-class FileAnnotatorHooks {
+class FileAnnotationsHooks {
        public static function onRegistration() {
                return true;
        }
@@ -32,13 +32,13 @@
 
        public static function getModulesForFilePage( &$out, &$skin ) {
                if ( $out->getTitle()->inNamespace( NS_FILE ) ) {
-                       $out->addModules( array( 'fileannotator' ) );
+                       $out->addModules( array( 'fileannotations' ) );
                }
        }
 
        public static function onParserSetup( Parser $parser ) {
-               $parser->setHook( 'annotation', 
'FileAnnotatorHooks::renderAnnotation' );
-               $parser->setHook( 'annotatedfile', 
'FileAnnotatorHooks::renderAnnotatedFile' );
+               $parser->setHook( 'annotation', 
'FileAnnotationsHooks::renderAnnotation' );
+               $parser->setHook( 'annotatedfile', 
'FileAnnotationsHooks::renderAnnotatedFile' );
                return true;
        }
@@ -1,6 +1,6 @@
 <?php
 /**
- * Hooks for FileAnnotator extension
+ * Hooks for FileAnnotations extension
  *
  * This program is free software; you can redistribute it and/or modify
 
diff --git a/resources/src/fileannotator.js b/resources/src/fileannotations.js
similarity index 100%
rename from resources/src/fileannotator.js
rename to resources/src/fileannotations.js
diff --git a/resources/src/fileannotator.less 
b/resources/src/fileannotations.less
similarity index 100%
rename from resources/src/fileannotator.less
rename to resources/src/fileannotations.less

-- 
To view, visit https://gerrit.wikimedia.org/r/294112
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I1fd7f6ff9b5a7238393b91f22ab7b0e751891fb8
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/extensions/FileAnnotations
Gerrit-Branch: master
Gerrit-Owner: MarkTraceur <[email protected]>

_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to